@@ -10,7 +10,9 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "kdenlivecore_export.h"
 #include "undohelper.hpp"
 #include "utils/timecode.h"
+
 #include <KSharedDataCache>
+
 #include <QColor>
 #include <QMutex>
 #include <QObject>
@@ -18,12 +20,12 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <QTextEdit>
 #include <QThreadPool>
 #include <QUrl>
-#include <knewstuff_version.h>
+
 #include <memory>
 #include <unordered_set>
 
-#include <mlt++/MltProfile.h>
 #include <mlt++/MltPlaylist.h>
+#include <mlt++/MltProfile.h>
 
 class Bin;
 class DocUndoStack;
@@ -46,8 +48,8 @@ class GuidesList;
 class TimeRemap;
 
 namespace Mlt {
-    class Repository;
-    class Producer;
+class Repository;
+class Producer;
 } // namespace Mlt
 
 #define EXIT_RESTART (42)
@@ -82,7 +84,7 @@ public:
      * with Mlt
      * @param MltPath (optional) path to MLT environment
      */
-    static bool build(const QString &packageType, bool testMode = false);
+    static bool build(LinuxPackageType packageType, bool testMode = false);
 
     void initHeadless(const QUrl &url);
 
@@ -97,7 +99,7 @@ public:
      * a default new file will be created.
      * @param clipsToLoad
      */
-    void initGUI(bool inSandbox, const QString &MltPath, const QUrl &Url, const QString &clipsToLoad = QString());
+    void initGUI(const QString &MltPath, const QUrl &Url, const QString &clipsToLoad = QString());
 
     /** @brief Returns a pointer to the singleton object. */
     static std::unique_ptr<Core> &self();
@@ -176,12 +178,14 @@ public:
     void refreshProjectRange(QPair<int, int> range);
     /** @brief Request project monitor refresh if referenced item is under cursor */
     void refreshProjectItem(const ObjectId &id);
+    /** @brief Returns true if position pos is inside the item */
+    bool itemContainsPos(const ObjectId &id, int pos);
     /** @brief Returns a reference to a monitor (clip or project monitor) */
     Monitor *getMonitor(int id);
     /** @brief Seek a monitor to position */
     void seekMonitor(int id, int position);
     /** @brief Returns timeline's active track info (position and tag) */
-    QPair <int,QString> currentTrackInfo() const;
+    QPair<int, QString> currentTrackInfo() const;
     /** @brief This function must be called whenever the profile used changes */
     void profileChanged();
 
@@ -217,13 +221,13 @@ public:
     double getClipSpeed(ObjectId id) const;
     /** @brief Mark an item as invalid for timeline preview */
     void invalidateItem(ObjectId itemId);
-    void invalidateRange(QPair<int, int>range);
+    void invalidateRange(QPair<int, int> range);
     void prepareShutdown();
     void finishShutdown();
     /** the keyframe model changed (effect added, deleted, active effect changed), inform timeline */
     void updateItemKeyframes(ObjectId id);
     /** A fade for clip id changed, update timeline */
-    void updateItemModel(ObjectId id, const QString &service);
+    void updateItemModel(ObjectId id, const QString &service, const QString &updatedParam);
     /** Show / hide keyframes for a timeline clip */
     void showClipKeyframes(ObjectId id, bool enable);
     Mlt::Profile &thumbProfile();
@@ -258,9 +262,11 @@ public:
     /** @brief An error occurred within a filter, inform user */
     void processInvalidFilter(const QString &service, const QString &id, const QString &message);
     /** @brief Update current project's tags */
-    void updateProjectTags(int previousCount, const QMap <int, QStringList> &tags);
+    void updateProjectTags(int previousCount, const QMap<int, QStringList> &tags);
     /** @brief Returns the project profile */
     Mlt::Profile &getProjectProfile();
+    /** @brief Returns the project profile frame rate num/den */
+    std::pair<int, int> getProjectFpsInfo() const;
     /** @brief Returns the consumer profile, that will be scaled
      *  according to preview settings. Should only be used on the consumer */
     Mlt::Profile &getMonitorProfile();
@@ -275,7 +281,7 @@ public:
     /** @brief Returns number of audio channels for this project. */
     int audioChannels();
     /** @brief Add guides in the project. */
-    void addGuides(const QList <int> &guides);
+    void addGuides(const QList<int> &guides);
     /** @brief Temporarily un/plug a list of clips in timeline. */
     void temporaryUnplug(const QList<int> &clipIds, bool hide);
     /** @brief Transcode a video file. */
@@ -299,18 +305,12 @@ public:
     void clearTimeRemap();
     /** @brief Create the dock widgets */
     void buildDocks();
-#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 98, 0)
-    /** @brief Instantiates a "Get Hot New Stuff" dialog.
-     * @param configFile configuration file for KNewStuff
-     * @return number of installed items */
-    int getNewStuff(const QString &configFile);
-#endif
     /** @brief Get the frame size of the clip above a composition */
     const QSize getCompositionSizeOnTrack(const ObjectId &id);
     void loadTimelinePreview(const QUuid uuid, const QString &chunks, const QString &dirty, bool enablePreview, Mlt::Playlist &playlist);
     /** @brief Returns true if the audio mixer widget is visible */
     bool audioMixerVisible{false};
-    QString packageType() { return m_packageType; };
+    LinuxPackageType packageType() { return m_packageType; };
     /** @brief Start / stop audio capture */
     void switchCapture();
     /** @brief Get the uuid of currently active timeline */
@@ -346,7 +346,7 @@ public:
     void updateHoverItem(const QUuid &uuid);
 
 private:
-    explicit Core(const QString &packageType);
+    explicit Core(LinuxPackageType packageType);
     static std::unique_ptr<Core> m_self;
 
     /** @brief Makes sure Qt's locale and system locale settings match. */
@@ -368,7 +368,7 @@ private:
     QString m_currentProfile;
 
     QString m_profile;
-    QString m_packageType;
+    LinuxPackageType m_packageType;
     Timecode m_timecode;
     Mlt::Profile m_thumbProfile;
     /** @brief Mlt profile used in the consumer 's monitors */
@@ -394,7 +394,8 @@ public Q_SLOTS:
     /** @brief Add an action to the app's actionCollection */
     void addActionToCollection(const QString &name, QAction *action);
     /** @brief display a user info/warning message in the project bin */
-    void displayBinMessage(const QString &text, int type, const QList<QAction *> &actions = QList<QAction *>(), bool showClose = false, BinMessage::BinCategory messageCategory = BinMessage::BinCategory::NoMessage);
+    void displayBinMessage(const QString &text, int type, const QList<QAction *> &actions = QList<QAction *>(), bool showClose = false,
+                           BinMessage::BinCategory messageCategory = BinMessage::BinCategory::NoMessage);
     void displayBinLogMessage(const QString &text, int type, const QString logInfo);
     /** @brief Create small thumbnails for luma used in compositions */
     void buildLumaThumbs(const QStringList &values);
@@ -407,7 +408,7 @@ public Q_SLOTS:
     /** @brief Set current project modified. */
     void setDocumentModified();
     /** @brief Show currently selected effect zone in timeline ruler. */
-    void showEffectZone(ObjectId id, QPair <int, int>inOut, bool checked);
+    void showEffectZone(ObjectId id, QPair<int, int> inOut, bool checked);
     void updateMasterZones();
     /** @brief Open the proxies test dialog. */
     void testProxies();
@@ -429,7 +430,7 @@ public Q_SLOTS:
 Q_SIGNALS:
     void coreIsReady();
     void updateLibraryPath();
-    //void updateMonitorProfile();
+    // void updateMonitorProfile();
     /** @brief Call config dialog on a selected page / tab */
     void showConfigDialog(Kdenlive::ConfigPage, int);
     void finalizeRecording(const QUuid uuid, const QString &captureFile);
@@ -459,7 +460,7 @@ Q_SIGNALS:
     /** @brief Emitted when a clip is resized (to handle clip monitor inserted zones) */
     void clipInstanceResized(const QString &binId);
     /** @brief Contains the project audio levels */
-    void audioLevelsAvailable(const QVector<double>& levels);
+    void audioLevelsAvailable(const QVector<double> &levels);
     /** @brief A frame was displayed in monitor, update audio mixer */
     void updateMixerLevels(int pos);
     /** @brief Audio recording was started or stopped*/
@@ -486,4 +487,6 @@ Q_SIGNALS:
     void mltWarning(const QString &message);
     /** @brief Request display of effect stack for a Bin clip. */
     void requestShowBinEffectStack(const QString &clipName, std::shared_ptr<EffectStackModel>, QSize frameSize, bool showKeyframes);
+    /** @brief Save guide categories in document properties */
+    void saveGuideCategories();
 };
